@@ -10,7 +10,7 @@ import {
 
 import * as utils from './utils';
 
-import { MODULE_VERSION } from './version';
+import { MODEL_VERSION } from './version';
 
 import { ToolbarView } from './toolbar_widget';
 
@@ -30,8 +30,8 @@ export class MPLCanvasModel extends DOMWidgetModel {
             _view_name: 'MPLCanvasView',
             _model_module: 'jupyter-matplotlib',
             _view_module: 'jupyter-matplotlib',
-            _model_module_version: '^' + MODULE_VERSION,
-            _view_module_version: '^' + MODULE_VERSION,
+            _model_module_version: MODEL_VERSION,
+            _view_module_version: MODEL_VERSION,
             header_visible: true,
             footer_visible: true,
             toolbar: null,
@@ -509,6 +509,7 @@ export class MPLCanvasView extends DOMWidgetView {
         top_canvas.style.top = '0';
         top_canvas.style.zIndex = '1';
 
+        top_canvas.addEventListener('dblclick', this.mouse_event('dblclick'));
         top_canvas.addEventListener(
             'mousedown',
             this.mouse_event('button_press')
